Vitu

vitu 初版已发布，请访问官网了解和查询相关信息！ https://vitu.ai

vitu是实现对包含加密货币在内的区块链数据从数据采集、清洗加工到量化研究、策略回测乃至实盘交易的一个专业量化服务平台，满足

对区块链在数据获取、量化研究和交易等方面的需求，它的特点是数据覆盖范围广，量化策略与交易框架专业且易懂,使用简捷方便。

欢迎关注扫描vitu的微信公众号“Vitu”,更多原创文章与信息与您分享，敬请期待。
<br>
Dependencies <br>=======
python 3.x

pandas

numpy
<br>
Installation<br>=======
-方式1：pip install vitu
-方式2：访问 https://github.com/Wanxiang-Blockchain-Hackathon-2020/N01-Vitu/ 下载安装
<br>
Quick Start<br>=======
  1 策略教程：在https://vitu.ai 上注册，《等你来学》栏目中查找vitu策略教程，其中包含数据下载和策略编辑方法。<br>
  2 如何回测：<br>
   --(1)若按方式1中直接安装vitu的,则可按照策略教程直接编辑策略进行回测;<br>
  若按照方式2 下载安装，则可选择下面两种方式之一进行策略回测：<br>
   --(2)在cmd（或Anaconda PowerShell Prompt）中，cd 文件目录地址（即setup.py所在的文件夹目录），enter, 再运行python setup.py install 完成vitu的安装，则可按照策略教程直接编辑策略进行回测。 <br>
   --(3)或者直接设置系统的环境变量，将文件目录地址（即setup.py所在的文件夹目录）加入到PYTHONPATH中，然后在此文件目录中直接按照教程编辑策略进行回测。<br>
 3 策略编辑：参照vitu策略教程，以demo.py为策略操作样本，可按照demo中的模板输入相关信息（账户信息，回测品种，数量，时间，交易条件，交易费用等），完成策略的回测 
